@@ -24,14 +24,14 @@
 #include <KActionCollection>
 #include <KConfig>
 #include <KEditToolBar>
-#include <KFileDialog>
+#include <QFileDialog>
 #include <KShortcutsDialog>
-#include <KLibLoader>
+#include <KPluginLoader>
 #include <KMessageBox>
 #include <KStandardAction>
-#include <KStatusBar>
+#include <QStatusBar>
 #include <QIcon>
-#include <KLocale>
+#include <KLocalizedString>
 #include <QTabWidget>
 #include <KConfigDialog>
 #include <KTextEdit>
@@ -52,7 +52,7 @@
 #include "lib/backend.h"
 #include "lib/panelpluginhandler.h"
 #include "lib/panelplugin.h"
-
+#include "lib/worksheetaccess.h"
 
 #include "settings.h"
 #include "ui_settings.h"
@@ -188,7 +188,7 @@ void CantorShell::fileOpen()
     // this slot is called whenever the File->Open menu is selected,
     // the Open shortcut is pressed (usually CTRL+O) or the Open toolbar
     // button is clicked
-    QUrl url = KFileDialog::getOpenUrl( QUrl(), i18n("*.cws|Cantor Worksheet"), this );
+    QUrl url = QFileDialog::getOpenFileUrl(this, i18n("Open file"), QUrl(), i18n("*.cws|Cantor Worksheet"));
 
     if (url.isEmpty() == false)
     {
@@ -585,3 +585,23 @@ void CantorShell::updatePanel()
     }
     plugActionList(QLatin1String("new_worksheet_with_backend_list"), newBackendActions);
 }
+
+Cantor::WorksheetAccessInterface* CantorShell::currentWorksheetAccessInterface()
+{
+    Cantor::WorksheetAccessInterface* wa=m_part->findChild<Cantor::WorksheetAccessInterface*>(Cantor::WorksheetAccessInterface::Name);
+
+    if (!wa)
+        qDebug()<<"failed to access worksheet access interface for current part";
+
+    return wa;
+}
+
+
+
+
+
+
+
+
+
+
